==> m4e_sdk-0.0.3-dev.3.tar.gz: lib/src/models/wallet.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter/foundation.dart';

import '../core/core.dart';

class M4eWalletType {
  final String _type;

  const M4eWalletType._(this._type);

  // Template
  static const bascule = M4eWalletType._('BASCULE');

  static M4eWalletType parse(String type) {
    return M4eWalletType._(type);
  }

  @override
  operator ==(cmp) => (cmp is M4eWalletType) && cmp._type == _type;

  @override
  int get hashCode => _type.hashCode;

  @override
  String toString() => _type;
}

class M4eWalletInfo extends Equatable {
  final String label;
  final String currency;
  final M4eWalletType type;

  const M4eWalletInfo._(this.label, this.currency, this.type);

  factory M4eWalletInfo({
    @required String label,
    @required String currency,
    M4eWalletType type = M4eWalletType.bascule,
  }) {
    assert(label != null, 'WalletInfo [label] should not be null');
    assert(currency != null, 'WalletInfo [currency] should not be null');
    assert(type != null, 'WalletInfo [type] should not be null');
    return M4eWalletInfo._(label, currency, type);
  }

  factory M4eWalletInfo.fromJson(Map<String, dynamic> json) {
    return M4eWalletInfo(
      label: json['label'],
      currency: json['currency'],
      type: M4eWalletType.parse(json['type']),
    );
  }

  @override
  List<Object> get props => [
        label,
        currency,
        type,
      ];

  @override
  String toString() =>
      'M4eWalletInfo(label: $label, currency: $currency, type: $type)';
}

class M4eWallet extends Equatable {
  final M4eUniqueId id;
  final M4eWalletInfo walletInfo;

  const M4eWallet._(this.id, this.walletInfo);

  factory M4eWallet(
      {@required M4eUniqueId id, @required M4eWalletInfo walletInfo}) {
    assert(id != null, 'Wallet [id] should not be null');
    assert(walletInfo != null, 'Wallet [walletInfo] should not be null');
    return M4eWallet._(id, walletInfo);
  }

  factory M4eWallet.fromJson(Map<String, dynamic> json) {
    return M4eWallet(
      id: json['id'],
      walletInfo: M4eWalletInfo(
        label: json['wallet']['label'],
        currency: json['wallet']['currency'],
        type: M4eWalletType.parse(json['wallet']['type']),
      ),
    );
  }

  Map<String, dynamic> toMap() {
    return {
      'id': this.id.toString(),
      'wallet': {
        'label': this.walletInfo.label,
        'currency': this.walletInfo.currency,
        'type': this.walletInfo.type.toString()
      }
    };
  }

  @override
  List<Object> get props => [id, walletInfo];

  @override
  String toString() =>
      'M4eWallet(id: ${id.value.toString()}, walletInfo: ${walletInfo.toString()})';
}

==> m4e_sdk-0.0.4-dev.2.tar.gz: lib/src/models/wallet.dart <==
import 'package:equatable/equatable.dart';
import 'package:flutter/foundation.dart';

import '../core/core.dart';
import '../models/models.dart';

class M4eWalletInfo extends Equatable {
  final String label;
  final M4eCurrencyType currency;
  final M4eWalletType type;

  const M4eWalletInfo._(this.label, this.currency, this.type);

  factory M4eWalletInfo({
    @required String label,
    @required M4eCurrencyType currency,
    M4eWalletType type = M4eWalletType.bascule,
  }) {
    assert(label != null, 'WalletInfo [label] should not be null');
    assert(currency != null, 'WalletInfo [currency] should not be null');
    assert(type != null, 'WalletInfo [type] should not be null');
    return M4eWalletInfo._(label, currency, type);
  }

  factory M4eWalletInfo.fromJson(Map<String, dynamic> json) {
    return M4eWalletInfo(
      label: json['label'],
      currency: M4eCurrencyType.parse(json['currency']),
      type: M4eWalletType.parse(json['type']),
    );
  }

  @override
  List<Object> get props => [
        label,
        currency,
        type,
      ];

  @override
  String toString() =>
      'M4eWalletInfo(label: $label, currency: ${currency.toString()}, type: $type)';
}

class M4eWallet extends Equatable {
  final M4eUniqueId id;
  final M4eWalletInfo walletInfo;

  const M4eWallet._(this.id, this.walletInfo);

  factory M4eWallet(
      {@required M4eUniqueId id, @required M4eWalletInfo walletInfo}) {
    assert(id != null, 'Wallet [id] should not be null');
    assert(walletInfo != null, 'Wallet [walletInfo] should not be null');

    return M4eWallet._(id, walletInfo);
  }

  factory M4eWallet.fromJson(Map<String, dynamic> json) {
    return M4eWallet(
      id: M4eUniqueId.fromUniqueString(json['id']),
      walletInfo: M4eWalletInfo.fromJson(json['wallet']),
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'id': this.id.toString(),
      'wallet': {
        'label': this.walletInfo.label,
        'currency': this.walletInfo.currency.toString(),
        'type': this.walletInfo.type.toString()
      }
    };
  }

  @override
  List<Object> get props => [id, walletInfo];

  @override
  String toString() =>
      'M4eWallet(id: ${id.toString()}, walletInfo: ${walletInfo.toString()})';
}

class M4eWalletList extends Equatable {
  final List<M4eWallet> wallets;

  const M4eWalletList({@required this.wallets});

  factory M4eWalletList.fromJson(Map<String, dynamic> json) {
    final _data = json['result'] as List;

    return M4eWalletList(
        wallets: _data?.map((e) => M4eWallet.fromJson(e))?.toList() ?? []);
  }

  Map<String, dynamic> toJson() {
    return {
      'result': this.wallets?.map((e) => e.toJson())?.toList() ?? [],
    };
  }

  @override
  List<Object> get props => [wallets];

  @override
  String toString() => 'M4eWalletList(wallets: $wallets)';
}
